import babel from "rollup-plugin-babel";
import resolve from "rollup-plugin-node-resolve";
import commonjs from "@rollup/plugin-commonjs";
import vue from "rollup-plugin-vue";
import image from "@rollup/plugin-image";
import postcss from "rollup-plugin-postcss";
import alias from "rollup-plugin-alias";
import path from "path";
// 处理css定义的变量
import simplevars from "postcss-simple-vars";
// 处理less嵌套样式写法
import nested from "postcss-nesting";
const pathResolve = (p) => path.resolve(__dirname, p);
import { terser } from "rollup-plugin-terser";
import requireContext from "rollup-plugin-require-context";

const config = [
  {
    input: "./src/index.js", // 入口文件
    external: ["lodash"], // 排除的依赖包
    output: {
      name: "index",
      file: "dist/component.js", // 打包后的index文件
      format: "esm", // umd格式 可换成 iife
      globals: {
        vue: "Vue",
      },
      inlineDynamicImports: true,
      // sourcemap: true,
    },
    plugins: [
      alias({
        entries: [{ find: "@", replacement: pathResolve("src") }],
      }),
      resolve(),
      vue({
        css: true,
        compileTemplate: true,
      }),
      babel({
        // 排除node_modules文件夹下，只编译自己的源代码
        exclude: "node_modules/**",
        extensions: [".js", ".vue"],
      }),
      commonjs(),
      image(),
      postcss({
        plugins: [nested(), simplevars()],
      }),
      requireContext(),
      // terser(),
    ],
  },
];

export default config;
