import ValidatorFactory from "./validator/Factory";
import CalculatorFactory from "./calculator/Factory";

export default class Field {
  /**
   * 表单字段类
   * @param {*} def         字段定义
   * @param {*} formData    表单对象
   * @param {*} formFields  表单包含的字段组件
   */
  constructor(def, formData, formFields) {
    if (!def || !formData || !formFields) return;
    //
    this.def = def;
    this.formData = formData;
    this.formFields = formFields;
  }

  /**
   * 生成校验规则
   */
  genValidatorRules() {
    const rules = [];
    // 必填项校验规则
    if (this.def.required === true) {
      rules.push(
        ValidatorFactory.createRequiredValidator(this.def.label).genRule()
      );
    }
    let validators = this.def.options?.validators;
    if (Array.isArray(validators)) {
      // 其他校验器规则
      validators.forEach((val) => {
        const validator = ValidatorFactory.createValidator(
          this.def.name,
          this.def.label,
          this.def.type,
          val,
          this.formData,
          this.formFields
        );
        if (validator) {
          rules.push(validator.genRule());
        }
      });
    }
    return rules;
  }

  /**
   * 计算隐藏字段的值
   */
  calcHiddenValue() {
    if (this.def.options?.hidden !== true) return;
    // 获取计算表达式
    const expression = this.def.options?.expression;
    if (!expression || !Array.isArray(expression) || expression.length < 2)
      return;
    // 生成计算器
    const calculator = CalculatorFactory.createCalculator(
      expression,
      this.formData,
      this.formFields
    );
    if (!calculator) return;
    // 获取计算值
    const value = calculator.calc();
    this.formData[this.def.name] = value;
    return value;
  }
}
