const SHARE_DATA_KEY_PREFIX = "__SHARE_DATA_CACHE__";

/**
 * 设置共享数据
 * @param {*} key
 * @param {*} data
 * @returns
 */
const setShareData = (key, data) => {
  if (!key) return;
  const shareKey = genShareDataKey(key);
  try {
    localStorage.setItem(shareKey, JSON.stringify(data));
    return true;
  } catch (e) {
    console.log("存储共享数据失败：", e);
  }
  return false;
};

/**
 * 获取共享数据
 * @param {*} key
 * @returns
 */
const getShareData = (key) => {
  if (!key) return;
  const shareKey = genShareDataKey(key);
  try {
    const data = localStorage.getItem(shareKey);
    return JSON.parse(data);
  } catch (e) {
    console.log("获取共享数据失败：", e);
  }
};

/**
 * 删除共享数据
 * @param {*} key
 * @returns
 */
const removeShareData = (key) => {
  if (!key) return;
  const shareKey = genShareDataKey(key);
  localStorage.removeItem(shareKey);
};

const genShareDataKey = (key) => {
  return `${SHARE_DATA_KEY_PREFIX}${key}`;
};

export default {
  setShareData,
  getShareData,
  removeShareData,
};
